@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,18 +20,13 @@ namespace ELF {
 
 void init_c_segments(Elf_Binary_t* c_binary, Binary* binary) {
 
-  it_segments segments = binary->segments();
+  Binary::it_segments segments = binary->segments();
   c_binary->segments = static_cast<Elf_Segment_t**>(
       malloc((segments.size() + 1) * sizeof(Elf_Segment_t**)));
   for (size_t i = 0; i < segments.size(); ++i) {
     Segment& segment = segments[i];
 
-    const std::vector<uint8_t>& segment_content = segment.content();
-    uint8_t* content = static_cast<uint8_t*>(malloc(segment_content.size() * sizeof(uint8_t)));
-    std::copy(
-        std::begin(segment_content),
-        std::end(segment_content),
-        content);
+    span<const uint8_t> segment_content = segment.content();
 
     c_binary->segments[i] = static_cast<Elf_Segment_t*>(malloc(sizeof(Elf_Segment_t)));
     c_binary->segments[i]->type            = static_cast<enum LIEF_ELF_SEGMENT_TYPES>(segment.type());
@@ -41,7 +36,8 @@ void init_c_segments(Elf_Binary_t* c_binary, Binary* binary) {
     c_binary->segments[i]->offset          = segment.file_offset();
     c_binary->segments[i]->alignment       = segment.alignment();
     c_binary->segments[i]->size            = segment_content.size();
-    c_binary->segments[i]->content         = content;
+    c_binary->segments[i]->content         = !segment_content.empty() ?
+                                             const_cast<uint8_t*>(segment_content.data()) : nullptr;
   }
 
   c_binary->segments[segments.size()] = nullptr;
@@ -54,7 +50,6 @@ void destroy_segments(Elf_Binary_t* c_binary) {
 
   Elf_Segment_t **segments = c_binary->segments;
   for (size_t idx = 0; segments[idx] != nullptr; ++idx) {
-    free(segments[idx]->content);
     free(segments[idx]);
   }
   free(c_binary->segments);
