@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,8 +13,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_ELF_UNDEF_H_
-#define LIEF_ELF_UNDEF_H_
+#ifndef LIEF_ELF_UNDEF_H
+#define LIEF_ELF_UNDEF_H
 
 #ifdef PT_LOAD
 #pragma message("LIEF will disable #define enums. Please use LIEF_ELF_XXXX or LIEF::ELF::XXXX instead!")
@@ -230,6 +230,8 @@
 #undef EM_NORC
 #undef EM_CSR_KALIMBA
 #undef EM_AMDGPU
+#undef EM_RISCV
+#undef EM_BPF
 
 
 #undef ELFCLASSNONE
@@ -399,6 +401,10 @@
 #undef SHT_LOUSER
 #undef SHT_HIUSER
 
+#undef SHT_ANDROID_REL
+#undef SHT_ANDROID_RELA
+#undef SHT_LLVM_ADDRSIG
+#undef SHT_RELR
 
 #undef SHF_NONE
 #undef SHF_WRITE
@@ -591,6 +597,17 @@
 #undef DT_MIPS_PLTGOT
 #undef DT_MIPS_RWPLT
 
+#undef DT_ANDROID_REL_OFFSET
+#undef DT_ANDROID_REL_SIZE
+#undef DT_ANDROID_REL
+#undef DT_ANDROID_RELSZ
+#undef DT_ANDROID_RELA
+#undef DT_ANDROID_RELASZ
+#undef DT_RELR
+#undef DT_RELRSZ
+#undef DT_RELRENT
+#undef DT_RELRCOUNT
+
 #undef DF_ORIGIN
 #undef DF_SYMBOLIC
 #undef DF_TEXTREL
@@ -666,6 +683,16 @@
 #undef NT_GNU_HWCAP
 #undef NT_GNU_BUILD_ID
 #undef NT_GNU_GOLD_VERSION
+#undef NT_GNU_BUILD_ATTRIBUTE_OPEN
+#undef NT_GNU_BUILD_ATTRIBUTE_FUNC
+#undef NT_PRSTATUS
+#undef NT_PRFPREG
+#undef NT_PRPSINFO
+#undef NT_TASKSTRUCT
+#undef NT_AUXV
+#undef NT_SIGINFO
+#undef NT_FILE
+#undef NT_PRXFPREG
 
 #undef ELF_NOTE_UNKNOWN
 #undef ELF_NOTE_OS_LINUX
@@ -1569,6 +1596,7 @@
 
 #undef AT_PLATFORM
 #undef AT_HWCAP
+#undef AT_HWCAP2
 #undef AT_FPUCW
 #undef AT_DCACHEBSIZE
 #undef AT_ICACHEBSIZE
@@ -1585,7 +1613,7 @@
 #undef AT_L2_CACHESHAPE
 #undef AT_L3_CACHESHAPE
 
-
+#undef NT_GNU_PROPERTY_TYPE_0
 
 
 #endif
