@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,28 +13,45 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#include "LIEF/logging++.hpp"
+
+#include <fstream>
+
+#include "logging.hpp"
 #include "LIEF/Abstract/Parser.hpp"
+#include "LIEF/Abstract/Binary.hpp"
+#include "LIEF/BinaryStream/BinaryStream.hpp"
 
-#include "LIEF/OAT.hpp"
 
+#if defined(LIEF_OAT_SUPPORT)
+#include "LIEF/OAT/Binary.hpp"
+#include "LIEF/OAT/Parser.hpp"
+#include "LIEF/OAT/utils.hpp"
+#endif
+
+#if defined(LIEF_ELF_SUPPORT)
 #include "LIEF/ELF/utils.hpp"
 #include "LIEF/ELF/Parser.hpp"
+#include "LIEF/ELF/Binary.hpp"
+#endif
 
+#if defined(LIEF_PE_SUPPORT)
 #include "LIEF/PE/utils.hpp"
 #include "LIEF/PE/Parser.hpp"
+#include "LIEF/PE/Binary.hpp"
+#endif
 
+#if defined(LIEF_MACHO_SUPPORT)
 #include "LIEF/MachO/utils.hpp"
 #include "LIEF/MachO/Parser.hpp"
+#include "LIEF/MachO/FatBinary.hpp"
+#include "LIEF/MachO/Binary.hpp"
+#endif
+
 
-#include "LIEF/exception.hpp"
 
 namespace LIEF {
-Parser::~Parser(void) = default;
-Parser::Parser(void) :
-  binary_size_{0},
-  binary_name_{""}
-{}
+Parser::~Parser() = default;
+Parser::Parser() = default;
 
 std::unique_ptr<Binary> Parser::parse(const std::string& filename) {
 
@@ -60,19 +77,16 @@ std::unique_ptr<Binary> Parser::parse(const std::string& filename) {
 #if defined(LIEF_MACHO_SUPPORT)
   if (MachO::is_macho(filename)) {
     // For fat binary we take the last one...
-    MachO::FatBinary* fat = MachO::Parser::parse(filename).release();
-    MachO::Binary* binary_return = nullptr;
-    if (fat) {
-      binary_return = fat->pop_back();
-      delete fat;
+    std::unique_ptr<MachO::FatBinary> fat = MachO::Parser::parse(filename);
+    if (fat != nullptr) {
+      return fat->pop_back();
     }
-    return std::unique_ptr<Binary>{binary_return};
+    return nullptr;
   }
 #endif
 
-  LOG(ERROR) << "Unknown format";
+  LIEF_ERR("Unknown format");
   return nullptr;
-
 }
 
 std::unique_ptr<Binary> Parser::parse(const std::vector<uint8_t>& raw, const std::string& name) {
@@ -99,36 +113,62 @@ std::unique_ptr<Binary> Parser::parse(const std::vector<uint8_t>& raw, const std
 #if defined(LIEF_MACHO_SUPPORT)
   if (MachO::is_macho(raw)) {
     // For fat binary we take the last one...
-    MachO::FatBinary* fat = MachO::Parser::parse(raw, name).release();
-    MachO::Binary* binary_return = nullptr;
-
-    if (fat) {
-      binary_return = fat->pop_back();
-      delete fat;
+    std::unique_ptr<MachO::FatBinary> fat = MachO::Parser::parse(raw, name);
+    if (fat != nullptr) {
+      return fat->pop_back();
     }
-    return std::unique_ptr<Binary>{binary_return};
+    return nullptr;
   }
 #endif
 
-  LOG(ERROR) << "Unknown format";
+  LIEF_ERR("Unknown format");
   return nullptr;
 
 }
 
+std::unique_ptr<Binary> Parser::parse(std::unique_ptr<BinaryStream> stream, const std::string& name) {
+
+#if defined(LIEF_ELF_SUPPORT)
+  if (ELF::is_elf(*stream)) {
+    return ELF::Parser::parse(std::move(stream), name);
+  }
+#endif
+
+
+#if defined(LIEF_PE_SUPPORT)
+  if (PE::is_pe(*stream)) {
+     return PE::Parser::parse(std::move(stream), name);
+  }
+#endif
+
+#if defined(LIEF_MACHO_SUPPORT)
+  if (MachO::is_macho(*stream)) {
+    // For fat binary we take the last one...
+    std::unique_ptr<MachO::FatBinary> fat = MachO::Parser::parse(std::move(stream));
+    if (fat != nullptr) {
+      return fat->pop_back();
+    }
+    return nullptr;
+  }
+#endif
+
+  LIEF_ERR("Unknown format");
+  return nullptr;
+}
+
 Parser::Parser(const std::string& filename) :
-  binary_size_{0},
   binary_name_{filename}
 {
   std::ifstream file(filename, std::ios::in | std::ios::binary);
 
-  if (file) {
-    file.unsetf(std::ios::skipws);
-    file.seekg(0, std::ios::end);
-    this->binary_size_ = static_cast<uint64_t>(file.tellg());
-    file.seekg(0, std::ios::beg);
-  } else {
-    throw LIEF::bad_file("Unable to open " + filename);
+  if (!file) {
+    LIEF_ERR("Can't open '{}'", filename);
+    return;
   }
+  file.unsetf(std::ios::skipws);
+  file.seekg(0, std::ios::end);
+  binary_size_ = static_cast<uint64_t>(file.tellg());
+  file.seekg(0, std::ios::beg);
 }
 
 }
