@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,17 @@
  * limitations under the License.
  */
 #include <array>
-#include <iostream>
+#include <ostream>
 #include <algorithm>
 #include <cmath>
 #include <iomanip>
+#include <utility>
 
+#include "LIEF/Visitor.hpp"
+
+#include "logging.hpp"
 #include "LIEF/Abstract/hash.hpp"
-#include "LIEF/exception.hpp"
+
 
 #include "LIEF/Abstract/Section.hpp"
 
@@ -28,70 +32,67 @@
 
 namespace LIEF {
 
-Section::Section(void) :
-  name_{""},
-  virtual_address_{0},
-  size_{0},
-  offset_{0}
+Section::Section() = default;
+
+Section::Section(std::string name) :
+  name_{std::move(name)}
 {}
 
 
-Section::Section(const std::string& name) :
-  name_{name},
-  virtual_address_{0},
-  size_{0},
-  offset_{0}
-{}
-
-
-Section::~Section(void) = default;
+Section::~Section() = default;
 Section& Section::operator=(const Section&) = default;
 Section::Section(const Section&) = default;
 
-const std::string& Section::name(void) const {
-  return this->name_;
+std::string Section::name() const {
+  return name_.c_str();
+}
+
+
+const std::string& Section::fullname() const {
+  return name_;
 }
 
 
 void Section::name(const std::string& name) {
-  this->name_ = name;
+  name_ = name;
 }
 
 
 void Section::content(const std::vector<uint8_t>&) {
-  throw not_supported("Not supported by this format");
+  LIEF_ERR("Not supported by this format");
 }
 
 
-std::vector<uint8_t> Section::content(void) const {
-  throw not_supported("Not supported by this format");
+span<const uint8_t> Section::content() const {
+  LIEF_ERR("Not supported by this format");
+  return {};
 }
 
 
-uint64_t Section::size(void) const {
-  return this->size_;
+uint64_t Section::size() const {
+  return size_;
 }
 
 
 void Section::size(uint64_t size) {
-  this->size_ = size;
+  size_ = size;
 }
 
-uint64_t Section::offset(void) const {
-  return this->offset_;
+uint64_t Section::offset() const {
+  return offset_;
 }
 
 
-uint64_t Section::virtual_address(void) const {
-  return this->virtual_address_;
+uint64_t Section::virtual_address() const {
+  return virtual_address_;
 }
 
 void Section::virtual_address(uint64_t virtual_address) {
-  this->virtual_address_ = virtual_address;;
+  virtual_address_ = virtual_address;;
 }
 
 void Section::offset(uint64_t offset) {
-  this->offset_ = offset;
+  offset_ = offset;
 }
 
 
@@ -99,7 +100,7 @@ void Section::offset(uint64_t offset) {
 // ================
 size_t Section::search(uint64_t integer, size_t pos, size_t size) const {
   if (size > sizeof(integer)) {
-    throw std::runtime_error("Invalid size (" + std::to_string(size) + ")");
+    return npos;
   }
 
   size_t minimal_size = size;
@@ -116,30 +117,24 @@ size_t Section::search(uint64_t integer, size_t pos, size_t size) const {
     else if (integer < std::numeric_limits<uint64_t>::max()) {
       minimal_size = sizeof(uint64_t);
     } else {
-      throw exception("Unable to find an appropriated type of " + std::to_string(integer));
+      return npos;
     }
   }
 
   std::vector<uint8_t> pattern(minimal_size, 0);
-
-  std::copy(
-      reinterpret_cast<const uint8_t*>(&integer),
-      reinterpret_cast<const uint8_t*>(&integer) + minimal_size,
-      pattern.data());
-
-  return this->search(pattern, pos);
+  memcpy(pattern.data(), &integer, minimal_size);
+  return search(pattern, pos);
 }
 
 size_t Section::search(const std::vector<uint8_t>& pattern, size_t pos) const {
-  std::vector<uint8_t> content = this->content();
+  span<const uint8_t> content = this->content();
 
-  auto&& it_found = std::search(
+  const auto it_found = std::search(
       std::begin(content) + pos, std::end(content),
-      std::begin(pattern), std::end(pattern)
-      );
+      std::begin(pattern), std::end(pattern));
 
   if (it_found == std::end(content)) {
-    return Section::npos;
+    return npos;
   }
 
   return std::distance(std::begin(content), it_found);
@@ -147,18 +142,18 @@ size_t Section::search(const std::vector<uint8_t>& pattern, size_t pos) const {
 
 size_t Section::search(const std::string& pattern, size_t pos) const {
   std::vector<uint8_t> pattern_formated = {std::begin(pattern), std::end(pattern)};
-  return this->search(pattern_formated, pos);
+  return search(pattern_formated, pos);
 }
 
 size_t Section::search(uint64_t integer, size_t pos) const {
-  return this->search(integer, pos, 0);
+  return search(integer, pos, 0);
 }
 
 // Search all functions
 // ====================
 std::vector<size_t> Section::search_all(uint64_t v, size_t size) const {
   std::vector<size_t> result;
-  size_t pos = this->search(v, 0, size);
+  size_t pos = search(v, 0, size);
 
   if (pos == Section::npos) {
     return result;
@@ -166,24 +161,27 @@ std::vector<size_t> Section::search_all(uint64_t v, size_t size) const {
 
   do {
     result.push_back(pos);
-    pos = this->search(v, pos + 1, size);
+    pos = search(v, pos + 1, size);
   } while(pos != Section::npos);
 
   return result;
 }
 
 std::vector<size_t> Section::search_all(uint64_t v) const {
-  return this->search_all(v, 0);
+  return search_all(v, 0);
 }
 
 std::vector<size_t> Section::search_all(const std::string& v) const {
-  return this->search_all_<std::string>(v);
+  return search_all_<std::string>(v);
 }
 
 
-double Section::entropy(void) const {
+double Section::entropy() const {
   std::array<uint64_t, 256> frequencies = { {0} };
-  const std::vector<uint8_t>& content = this->content();
+  span<const uint8_t> content = this->content();
+  if (content.size() == 0) {
+    return 0.;
+  }
   for (uint8_t x : content) {
     frequencies[x]++;
   }
@@ -192,7 +190,7 @@ double Section::entropy(void) const {
   for (uint64_t p : frequencies) {
     if (p > 0) {
       double freq = static_cast<double>(p) / static_cast<double>(content.size());
-      entropy += freq * std::log2(freq) ;
+      entropy += freq * std::log2l(freq) ;
     }
   }
   return (-entropy);
@@ -205,13 +203,16 @@ void Section::accept(Visitor& visitor) const {
 
 
 bool Section::operator==(const Section& rhs) const {
+  if (this == &rhs) {
+    return true;
+  }
   size_t hash_lhs = AbstractHash::hash(*this);
   size_t hash_rhs = AbstractHash::hash(rhs);
   return hash_lhs == hash_rhs;
 }
 
 bool Section::operator!=(const Section& rhs) const {
-  return not (*this == rhs);
+  return !(*this == rhs);
 }
 
 std::ostream& operator<<(std::ostream& os, const Section& entry) {
