@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,10 +14,14 @@
  * limitations under the License.
  */
 #include "LIEF/ELF/DynamicEntryRunPath.hpp"
+#include "LIEF/Visitor.hpp"
+#include "logging.hpp"
 
+#include <algorithm>
 #include <iomanip>
 #include <numeric>
 #include <sstream>
+#include <utility>
 
 namespace LIEF {
 namespace ELF {
@@ -26,48 +30,48 @@ namespace ELF {
 DynamicEntryRunPath& DynamicEntryRunPath::operator=(const DynamicEntryRunPath&) = default;
 DynamicEntryRunPath::DynamicEntryRunPath(const DynamicEntryRunPath&) = default;
 
-DynamicEntryRunPath::DynamicEntryRunPath(void) :
-  DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_RUNPATH, 0},
-  runpath_{}
+DynamicEntryRunPath::DynamicEntryRunPath() :
+  DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_RUNPATH, 0}
 {}
 
-DynamicEntryRunPath::DynamicEntryRunPath(const std::string& runpath) :
+DynamicEntryRunPath::DynamicEntryRunPath(std::string runpath) :
   DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_RUNPATH, 0},
-  runpath_{runpath}
+  runpath_{std::move(runpath)}
 {}
 
 
 DynamicEntryRunPath::DynamicEntryRunPath(const std::vector<std::string>& paths) :
-  DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_RUNPATH, 0},
-  runpath_{""}
+  DynamicEntry::DynamicEntry{DYNAMIC_TAGS::DT_RUNPATH, 0}
 {
   this->paths(paths);
 }
 
 
 
-const std::string& DynamicEntryRunPath::name(void) const {
-  return this->runpath_;
+const std::string& DynamicEntryRunPath::name() const {
+  return runpath_;
 }
 
 
 void DynamicEntryRunPath::name(const std::string& name) {
-  this->runpath_ = name;
+  runpath_ = name;
 }
 
-const std::string& DynamicEntryRunPath::runpath(void) const {
-  return this->name();
+const std::string& DynamicEntryRunPath::runpath() const {
+  return name();
 }
 
 void DynamicEntryRunPath::runpath(const std::string& runpath) {
-  this->name(runpath);
+  name(runpath);
 }
 
 
-std::vector<std::string> DynamicEntryRunPath::paths(void) const {
+std::vector<std::string> DynamicEntryRunPath::paths() const {
   std::stringstream ss;
-  ss.str(this->runpath());
+  ss.str(runpath());
+
   std::string path;
+
   std::vector<std::string> paths;
   while (std::getline(ss, path, DynamicEntryRunPath::delimiter)) {
     paths.push_back(path);
@@ -76,12 +80,11 @@ std::vector<std::string> DynamicEntryRunPath::paths(void) const {
 }
 
 void DynamicEntryRunPath::paths(const std::vector<std::string>& paths) {
-  this->runpath_ = std::accumulate(
-      std::begin(paths),
-      std::end(paths),
+  runpath_ = std::accumulate(
+      std::begin(paths), std::end(paths),
       std::string(""),
-      [] (std::string path, const std::string& new_entry) {
-        return path.empty() ? new_entry :  path + DynamicEntryRunPath::delimiter + new_entry;
+      [] (const std::string& path, const std::string& new_entry) {
+        return path.empty() ? new_entry : path + DynamicEntryRunPath::delimiter + new_entry;
       });
 }
 
@@ -94,25 +97,22 @@ DynamicEntryRunPath& DynamicEntryRunPath::append(const std::string& path) {
 
 DynamicEntryRunPath& DynamicEntryRunPath::remove(const std::string& path) {
   std::vector<std::string> paths = this->paths();
-  paths.erase(std::remove_if(
-        std::begin(paths),
-        std::end(paths),
-        [&path] (const std::string& p) {
-          return p == path;
-        }), std::end(paths));
+  paths.erase(std::remove_if(std::begin(paths), std::end(paths),
+                             [&path] (const std::string& p) { return p == path; }),
+              std::end(paths));
   this->paths(paths);
   return *this;
 }
 
-DynamicEntryRunPath& DynamicEntryRunPath::insert(size_t pos, const std::string path) {
+DynamicEntryRunPath& DynamicEntryRunPath::insert(size_t pos, const std::string& path) {
   std::vector<std::string> paths = this->paths();
 
   if (pos == paths.size()) {
-    return this->append(path);
+    return append(path);
   }
 
   if (pos > paths.size()) {
-    throw corrupted(std::to_string(pos) + " is out of ranges");
+    LIEF_ERR("pos: {:d} is out of range", pos);
   }
   paths.insert(std::begin(paths) + pos, path);
   this->paths(paths);
@@ -120,22 +120,27 @@ DynamicEntryRunPath& DynamicEntryRunPath::insert(size_t pos, const std::string p
 }
 
 DynamicEntryRunPath& DynamicEntryRunPath::operator+=(const std::string& path) {
-  return this->append(path);
+  return append(path);
 }
 
 DynamicEntryRunPath& DynamicEntryRunPath::operator-=(const std::string& path) {
-  return this->remove(path);
+  return remove(path);
 }
 
 void DynamicEntryRunPath::accept(Visitor& visitor) const {
   visitor.visit(*this);
 }
 
+bool DynamicEntryRunPath::classof(const DynamicEntry* entry) {
+  const DYNAMIC_TAGS tag = entry->tag();
+  return tag == DYNAMIC_TAGS::DT_RUNPATH;
+}
+
 std::ostream& DynamicEntryRunPath::print(std::ostream& os) const {
   DynamicEntry::print(os);
   os << std::hex
      << std::left
-     << std::setw(10) << this->name();
+     << std::setw(10) << name();
   return os;
 }
 }
