@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,41 +18,43 @@
 #include "LIEF/MachO/hash.hpp"
 
 #include "LIEF/MachO/MainCommand.hpp"
+#include "MachO/Structures.hpp"
 
 namespace LIEF {
 namespace MachO {
 
 MainCommand& MainCommand::operator=(const MainCommand&) = default;
 MainCommand::MainCommand(const MainCommand&) = default;
-MainCommand::~MainCommand(void) = default;
+MainCommand::~MainCommand() = default;
 
-MainCommand::MainCommand(void) :
-  LoadCommand::LoadCommand{},
-  entrypoint_{0},
-  stackSize_{0}
+MainCommand::MainCommand() = default;
+
+
+MainCommand::MainCommand(const details::entry_point_command& cmd) :
+  LoadCommand::LoadCommand{static_cast<LOAD_COMMAND_TYPES>(cmd.cmd), cmd.cmdsize},
+  entrypoint_{cmd.entryoff},
+  stack_size_{cmd.stacksize}
 {}
 
-MainCommand::MainCommand(const entry_point_command *cmd) :
-  LoadCommand::LoadCommand{static_cast<LOAD_COMMAND_TYPES>(cmd->cmd), cmd->cmdsize},
-  entrypoint_{cmd->entryoff},
-  stackSize_{cmd->stacksize}
-{}
-
-
-uint64_t MainCommand::entrypoint(void) const {
-  return this->entrypoint_;
+MainCommand* MainCommand::clone() const {
+  return new MainCommand(*this);
 }
 
-uint64_t MainCommand::stack_size(void) const {
-  return this->stackSize_;
+
+uint64_t MainCommand::entrypoint() const {
+  return entrypoint_;
+}
+
+uint64_t MainCommand::stack_size() const {
+  return stack_size_;
 }
 
 void MainCommand::entrypoint(uint64_t entrypoint) {
-  this->entrypoint_ = entrypoint;
+  entrypoint_ = entrypoint;
 }
 
 void MainCommand::stack_size(uint64_t stacksize) {
-  this->stackSize_ = stacksize;
+  stack_size_ = stacksize;
 }
 
 void MainCommand::accept(Visitor& visitor) const {
@@ -60,22 +62,33 @@ void MainCommand::accept(Visitor& visitor) const {
 }
 
 bool MainCommand::operator==(const MainCommand& rhs) const {
+  if (this == &rhs) {
+    return true;
+  }
   size_t hash_lhs = Hash::hash(*this);
   size_t hash_rhs = Hash::hash(rhs);
   return hash_lhs == hash_rhs;
 }
 
 bool MainCommand::operator!=(const MainCommand& rhs) const {
-  return not (*this == rhs);
+  return !(*this == rhs);
 }
 
+
+bool MainCommand::classof(const LoadCommand* cmd) {
+  // This must be sync with BinaryParser.tcc
+  const LOAD_COMMAND_TYPES type = cmd->command();
+  return type == LOAD_COMMAND_TYPES::LC_MAIN;
+}
+
+
 std::ostream& MainCommand::print(std::ostream& os) const {
   LoadCommand::print(os);
   os << std::hex;
   os << std::left
-     << "Entrypoint: " << "0x" << this->entrypoint()
+     << "Entrypoint: " << "0x" << entrypoint()
      << std::endl
-     << "Stack size: " << "0x" << this->stack_size();
+     << "Stack size: " << "0x" << stack_size();
   return os;
 }
 
