@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 #include <iomanip>
 
 #include "LIEF/PE/hash.hpp"
-#include "LIEF/exception.hpp"
+
 
 #include "LIEF/PE/LoadConfigurations.hpp"
 
@@ -25,32 +25,31 @@ namespace PE {
 
 LoadConfigurationV7& LoadConfigurationV7::operator=(const LoadConfigurationV7&) = default;
 LoadConfigurationV7::LoadConfigurationV7(const LoadConfigurationV7&) = default;
-LoadConfigurationV7::~LoadConfigurationV7(void) = default;
+LoadConfigurationV7::~LoadConfigurationV7() = default;
 
-LoadConfigurationV7::LoadConfigurationV7(void) :
-  LoadConfigurationV6{},
+LoadConfigurationV7::LoadConfigurationV7() :
   reserved3_{0},
   addressof_unicode_string_{0}
 {}
 
-WIN_VERSION LoadConfigurationV7::version(void) const {
+WIN_VERSION LoadConfigurationV7::version() const {
   return LoadConfigurationV7::VERSION;
 }
 
-uint32_t LoadConfigurationV7::reserved3(void) const {
-  return this->reserved3_;
+uint32_t LoadConfigurationV7::reserved3() const {
+  return reserved3_;
 }
 
-uint64_t LoadConfigurationV7::addressof_unicode_string(void) const {
-  return this->addressof_unicode_string_;
+uint64_t LoadConfigurationV7::addressof_unicode_string() const {
+  return addressof_unicode_string_;
 }
 
 void LoadConfigurationV7::reserved3(uint32_t value) {
-  this->reserved3_ = value;
+  reserved3_ = value;
 }
 
 void LoadConfigurationV7::addressof_unicode_string(uint64_t value) {
-  this->addressof_unicode_string_ = value;
+  addressof_unicode_string_ = value;
 }
 
 void LoadConfigurationV7::accept(Visitor& visitor) const {
@@ -58,19 +57,22 @@ void LoadConfigurationV7::accept(Visitor& visitor) const {
 }
 
 bool LoadConfigurationV7::operator==(const LoadConfigurationV7& rhs) const {
+  if (this == &rhs) {
+    return true;
+  }
   size_t hash_lhs = Hash::hash(*this);
   size_t hash_rhs = Hash::hash(rhs);
   return hash_lhs == hash_rhs;
 }
 
 bool LoadConfigurationV7::operator!=(const LoadConfigurationV7& rhs) const {
-  return not (*this == rhs);
+  return !(*this == rhs);
 }
 
 std::ostream& LoadConfigurationV7::print(std::ostream& os) const {
   LoadConfigurationV6::print(os);
 
-  os << std::setw(LoadConfiguration::PRINT_WIDTH) << std::setfill(' ') << "Reserved 3:" << std::hex << this->reserved3() << std::endl;
+  os << std::setw(LoadConfiguration::PRINT_WIDTH) << std::setfill(' ') << "Reserved 3:" << std::hex << reserved3() << std::endl;
   return os;
 }
 
