@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -13,8 +13,8 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-#ifndef LIEF_FROZEN_H_
-#define LIEF_FROZEN_H_
+#ifndef LIEF_FROZEN_H
+#define LIEF_FROZEN_H
 #include "LIEF/config.h"
 #include "compiler_support.h"
 
@@ -22,8 +22,8 @@
 #include <frozen/map.h>
 #define CONST_MAP(KEY, VAL, NUM) constexpr frozen::map<KEY, VAL, NUM>
 #else
-#include <map>
-#define CONST_MAP(KEY, VAL, NUM) static const std::map<KEY, VAL>
+#include <unordered_map>
+#define CONST_MAP(KEY, VAL, NUM) static const std::unordered_map<KEY, VAL>
 #endif
 
 #endif
