@@ -1,5 +1,5 @@
-/* Copyright 2017 R. Thomas
- * Copyright 2017 Quarkslab
+/* Copyright 2017 - 2023 R. Thomas
+ * Copyright 2017 - 2023 Quarkslab
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -90,9 +90,13 @@ size_t hash(const std::vector<uint8_t>& raw) {
   return Hash::hash(raw);
 }
 
-Hash::~Hash(void) = default;
+size_t hash(span<const uint8_t> raw) {
+  return Hash::hash(raw);
+}
 
-Hash::Hash(void) :
+Hash::~Hash() = default;
+
+Hash::Hash() :
   value_{0}
 {}
 
@@ -104,55 +108,63 @@ Hash::Hash(size_t init_value) :
 Hash& Hash::process(const Object& obj) {
   Hash hasher;
   obj.accept(hasher);
-  this->value_ = combine(this->value_, hasher.value());
+  value_ = combine(value_, hasher.value());
   return *this;
 }
 
 Hash& Hash::process(size_t integer) {
-  this->value_ = combine(this->value_, std::hash<size_t>{}(integer));
+  value_ = combine(value_, std::hash<size_t>{}(integer));
   return *this;
 }
 
 Hash& Hash::process(const std::string& str) {
-  this->value_ = combine(this->value_, std::hash<std::string>{}(str));
+  value_ = combine(value_, std::hash<std::string>{}(str));
   return *this;
 }
 
 
 Hash& Hash::process(const std::u16string& str) {
-  this->value_ = combine(this->value_, std::hash<std::u16string>{}(str));
+  value_ = combine(value_, std::hash<std::u16string>{}(str));
   return *this;
 }
 
 Hash& Hash::process(const std::vector<uint8_t>& raw) {
-  this->value_ = combine(this->value_, Hash::hash(raw));
+  value_ = combine(value_, Hash::hash(raw));
   return *this;
 }
 
-size_t Hash::value(void) const {
-  return this->value_;
+Hash& Hash::process(span<const uint8_t> raw) {
+  value_ = combine(value_, Hash::hash(raw));
+  return *this;
+}
+
+size_t Hash::value() const {
+  return value_;
 }
 
 
 // Static methods
 // ==============
 size_t Hash::hash(const std::vector<uint8_t>& raw) {
-  std::vector<uint8_t> sha256(32, 0);
-  mbedtls_sha256(raw.data(), raw.size(), sha256.data(), 0);
-
-  return std::accumulate(
-     std::begin(sha256),
-     std::end(sha256), 0,
-     [] (size_t v, uint8_t n) {
-        size_t r = v;
-        return (r << sizeof(uint8_t) * 8) | n;
-     });
+  return hash(raw.data(), raw.size());
 }
 
 
 size_t Hash::hash(const void* raw, size_t size) {
-  const uint8_t* start = reinterpret_cast<const uint8_t*>(raw);
-  return Hash::hash(std::vector<uint8_t>{start, start + size});
+  const auto* start = reinterpret_cast<const uint8_t*>(raw);
+
+  std::vector<uint8_t> sha256(32, 0u);
+  mbedtls_sha256(start, size, sha256.data(), 0);
+
+  return std::accumulate(std::begin(sha256), std::end(sha256), 0llu,
+     [] (size_t v, uint8_t n) {
+        return (v << sizeof(uint8_t) * 8u) | n;
+     });
+}
+
+
+size_t Hash::hash(span<const uint8_t> raw) {
+  return hash(raw.data(), raw.size());
 }
 
 }
